<!-- SPDX-License-Identifier: CC-BY-4.0 -->
<!-- Copyright Contributors to the Egeria project. -->

# Developer

These widgets display different kinds of information useful to developers. Widgets
will continue to be added over time to cover more facets. Useful developer information
can also be found on [Egeria Project](https://egeria-project.org) and in [Egeria Explorers](https://egeria-project.org/release-notes/june-2024/?h=brain#egeria-explorers).

* get_guid_info.py - lists information about the metadata element specified by the Egeria guid.
* get_tech_details.py - shows a tree view showing the Egeria support for a particular technology (e.g PostgreSQL Server).
* list_asset_types.py - provides a tree view of a collection with all nested collections and items within the collection.
* list_registered_services.py - lists the services available on an Egeria platform.
* list_relationship_types.py - list the relationships details for a specified Egeria type.
* list_tech_templates.py - list template details for technology types
* list_tech_types.py - list the technology types that Egeria currently supports
* list_valid_metadata_values.py - list valid metadata values for a particular property and category.




----
License: [CC BY 4.0](https://creativecommons.org/licenses/by/4.0/),
Copyright Contributors to the Egeria project.